package
Version:
v1.95.0
Opens a new window with list of versions in this module.
Published: Sep 11, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package game はメインゲームの実装を提供する。
MainGame はebiten.Game interfaceを満たす
func (*MainGame) Draw ¶
Draw はゲームの描画処理を行う
func (*MainGame) Layout ¶
Layout はinterface methodのため、シグネチャは変更できない
func (*MainGame) Update ¶
Update はゲームの更新処理を行う
Source Files
¶
Click to show internal directories.
Click to hide internal directories.